==> pmml-model-gwt-1.6.0.jar: org/dmg/pmml/time_series/FinalNoise.java <==

package org.dmg.pmml.time_series;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Array;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "FinalNoise", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "array"
})
@Added((org.dmg.pmml.Version.PMML_4_4))
@JsonRootName("FinalNoise")
@JsonPropertyOrder({
    "array"
})
public class FinalNoise
    extends org.dmg.pmml.PMMLObject
{

    @XmlElement(name = "Array", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Array")
    private Array array;
    private final static long serialVersionUID = 67371269L;

    public FinalNoise() {
    }

    @ValueConstructor
    public FinalNoise(
        @org.jpmml.model.annotations.Property("array")
        Array array) {
        this.array = array;
    }

    public Array getArray() {
        return array;
    }

    public FinalNoise setArray(
        @org.jpmml.model.annotations.Property("array")
        Array array) {
        this.array = array;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getArray());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.9.jar: org/dmg/pmml/time_series/FinalNoise.java <==

package org.dmg.pmml.time_series;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Array;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.MissingElementException;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "FinalNoise", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "array"
})
@JsonRootName("FinalNoise")
@JsonPropertyOrder({
    "array"
})
@Added((org.dmg.pmml.Version.PMML_4_4))
public class FinalNoise
    extends org.dmg.pmml.PMMLObject
{

    @XmlElement(name = "Array", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Array")
    private Array array;
    private final static long serialVersionUID = 67371271L;

    public FinalNoise() {
    }

    @ValueConstructor
    public FinalNoise(
        @org.jpmml.model.annotations.Property("array")
        Array array) {
        this.array = array;
    }

    public Array requireArray() {
        if (this.array == null) {
            throw new MissingElementException(this, PMMLElements.FINALNOISE_ARRAY);
        }
        return this.array;
    }

    public Array getArray() {
        return array;
    }

    public FinalNoise setArray(
        @org.jpmml.model.annotations.Property("array")
        Array array) {
        this.array = array;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getArray());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
